package mschmidt.komo.datatools;
/*
 * Instances of this object class are used to test the database connection.
 * This task is performed in a worker thread.
 */

import java.sql.Connection;
import mschmidt.komo.Application;
import mschmidt.komo.ApplicationActionBarAdvisor;
import mschmidt.komo.KomoPlugin;
import mschmidt.komo.ApplicationImages;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.progress.IProgressConstants;

public class TestConnectionJob extends Job {
	public TestConnectionJob(final String jobName) {
		super(jobName);
	}

	@Override
	protected final IStatus run(final IProgressMonitor monitor) {
		boolean testOK = false;
		try {
			setProperty(IProgressConstants.ICON_PROPERTY, KomoPlugin
					.getImageDescriptor(ApplicationImages.CONNECT_ICON));
			monitor.beginTask("Test Connection", 100);
			Application.dbConn.dbLock.acquire(5000);
			Connection thisConnection = Application.dbConn.getConnection();
			if (thisConnection != null) {
				testOK = true;
				Application.dbConn.closeConnection();
			}
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			monitor.done();
			Application.dbConn.dbLock.release();
			showResults(testOK);
		}
		return Status.OK_STATUS;
	}
/**
 * This method writes the results of the test to the status line.
 * @param testOK - True if connection was successful, false if not
 */
	protected final void showResults(final boolean testOK) {
		Display.getDefault().asyncExec(new Runnable() {
			public void run() {
				String dbMsg = new String();
				if (testOK) {
					dbMsg = "Successful connection with "
							+ Application.dbConn.getMessage();
				} else {
					dbMsg = Application.dbConn.getMessage();

				}
				ApplicationActionBarAdvisor.postMessage(dbMsg, !testOK);
			}
		});
	}

}
